@@ -117,6 +117,8 @@ from plaid.model.credit_filter import CreditFilter
 from plaid.model.customer_initiated_return_risk import CustomerInitiatedReturnRisk
 from plaid.model.customer_initiated_risk_tier import CustomerInitiatedRiskTier
 from plaid.model.deductions import Deductions
+from plaid.model.deductions_breakdown import DeductionsBreakdown
+from plaid.model.deductions_total import DeductionsTotal
 from plaid.model.default_update_webhook import DefaultUpdateWebhook
 from plaid.model.deposit_switch_address_data import DepositSwitchAddressData
 from plaid.model.deposit_switch_alt_create_request import DepositSwitchAltCreateRequest
@@ -132,18 +134,23 @@ from plaid.model.deposit_switch_target_user import DepositSwitchTargetUser
 from plaid.model.deposit_switch_token_create_request import DepositSwitchTokenCreateRequest
 from plaid.model.deposit_switch_token_create_response import DepositSwitchTokenCreateResponse
 from plaid.model.depository_filter import DepositoryFilter
-from plaid.model.distribution_details import DistributionDetails
+from plaid.model.distribution_breakdown import DistributionBreakdown
 from plaid.model.document_metadata import DocumentMetadata
 from plaid.model.earnings import Earnings
+from plaid.model.earnings_breakdown import EarningsBreakdown
 from plaid.model.earnings_total import EarningsTotal
 from plaid.model.email import Email
 from plaid.model.employee import Employee
 from plaid.model.employee_income_summary_field_string import EmployeeIncomeSummaryFieldString
 from plaid.model.employer import Employer
 from plaid.model.employer_income_summary_field_string import EmployerIncomeSummaryFieldString
+from plaid.model.employer_verification import EmployerVerification
 from plaid.model.employers_search_request import EmployersSearchRequest
 from plaid.model.employers_search_response import EmployersSearchResponse
 from plaid.model.employment_details import EmploymentDetails
+from plaid.model.employment_verification import EmploymentVerification
+from plaid.model.employment_verification_get_request import EmploymentVerificationGetRequest
+from plaid.model.employment_verification_get_response import EmploymentVerificationGetResponse
 from plaid.model.error import Error
 from plaid.model.external_payment_options import ExternalPaymentOptions
 from plaid.model.external_payment_refund_details import ExternalPaymentRefundDetails
@@ -166,14 +173,15 @@ from plaid.model.income_summary import IncomeSummary
 from plaid.model.income_summary_field_number import IncomeSummaryFieldNumber
 from plaid.model.income_summary_field_string import IncomeSummaryFieldString
 from plaid.model.income_verification_create_request import IncomeVerificationCreateRequest
+from plaid.model.income_verification_create_request_options import IncomeVerificationCreateRequestOptions
 from plaid.model.income_verification_create_response import IncomeVerificationCreateResponse
 from plaid.model.income_verification_documents_download_request import IncomeVerificationDocumentsDownloadRequest
-from plaid.model.income_verification_documents_download_response import IncomeVerificationDocumentsDownloadResponse
 from plaid.model.income_verification_paystub_get_request import IncomeVerificationPaystubGetRequest
 from plaid.model.income_verification_paystub_get_response import IncomeVerificationPaystubGetResponse
 from plaid.model.income_verification_paystubs_get_request import IncomeVerificationPaystubsGetRequest
 from plaid.model.income_verification_paystubs_get_response import IncomeVerificationPaystubsGetResponse
 from plaid.model.income_verification_precheck_employer import IncomeVerificationPrecheckEmployer
+from plaid.model.income_verification_precheck_employer_address import IncomeVerificationPrecheckEmployerAddress
 from plaid.model.income_verification_precheck_military_info import IncomeVerificationPrecheckMilitaryInfo
 from plaid.model.income_verification_precheck_request import IncomeVerificationPrecheckRequest
 from plaid.model.income_verification_precheck_response import IncomeVerificationPrecheckResponse
@@ -329,6 +337,7 @@ from plaid.model.paystub_ytd_details import PaystubYTDDetails
 from plaid.model.pending_expiration_webhook import PendingExpirationWebhook
 from plaid.model.personal_finance_category import PersonalFinanceCategory
 from plaid.model.phone_number import PhoneNumber
+from plaid.model.platform_ids import PlatformIds
 from plaid.model.processor_apex_processor_token_create_request import ProcessorApexProcessorTokenCreateRequest
 from plaid.model.processor_auth_get_request import ProcessorAuthGetRequest
 from plaid.model.processor_auth_get_response import ProcessorAuthGetResponse
